.. _dataformats_psf:

Point spread function
=====================

* `gtpsf <http://fermi.gsfc.nasa.gov/ssc/data/analysis/scitools/help/gtpsf.txt>`_ format can be read with `gammapy.irf.EnergyDependentTablePSF`.